==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-runner/lxqt-runner_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation type="vanished">LXQt-runner ezarpenak</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Itxura</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Posizioa:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Erakutsi hemen:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Lasterbidea:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Pantailaren goiko ertza</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Pantailaren erdia</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Monitorea sagua dagoen lekuan</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Beti %1 monitorean</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Aplikazio-abiarazlea</translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation type="vanished">Konfiguratu lxqt-runner</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation type="vanished">Garbitu lxqt-runner historia</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation type="vanished">Sakatu &quot;%1&quot; elkarrizketa-koadroa ikusteko.</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="93"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="97"/>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="349"/>
        <source>Show/hide runner dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="801"/>
        <source>Mathematics</source>
        <translation>Matematikak</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation type="vanished">LXQt energia-kudeaketa</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-runner/lxqt-runner_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation type="vanished">LXQt-runner ezarpenak</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Itxura</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Posizioa:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Erakutsi hemen:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Lasterbidea:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Pantailaren goiko ertza</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Pantailaren erdia</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Monitorea sagua dagoen lekuan</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Beti %1 monitorean</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Aplikazio-abiarazlea</translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation type="vanished">Konfiguratu lxqt-runner</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation type="vanished">Garbitu lxqt-runner historia</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation type="vanished">Sakatu &quot;%1&quot; elkarrizketa-koadroa ikusteko.</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="822"/>
        <source>Mathematics</source>
        <translation>Matematikak</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation type="vanished">LXQt energia-kudeaketa</translation>
    </message>
</context>
</TS>
